{{ cookiecutter.__project_name_slug }}
{{ '=' * (cookiecutter.__project_name_slug | length) }}

Description
-----------

{{ cookiecutter.__short_description }}


How to install
--------------


How to develop
--------------


How to build
------------


How to deploy
-------------
